/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TCentralComponent.h"
#include "TListBoxModel.h"
//---------------------------------------------------------------------
#define tr(s) String::fromUTF8(s)
//---------------------------------------------------------------------
TCentralComponent::TCentralComponent() : Component("Central Component"),
                                         pAddButton(0),
                                         pDeleteButton(0)
{
    // Создаём экземпляр модели данных
    pListBoxModel = new TListBoxModel();
    
    // Задаём эту модель в качестве источника данных при создании списка
    pList = new ListBox("List", pListBoxModel);
    pList->setOutlineThickness(2);
    pList->setMultipleSelectionEnabled(false);
    pList->addKeyListener(this);
    addAndMakeVisible(pList);

    pInputEdit = new TextEditor("Input Edit");
    pInputEdit->setMultiLine(false, false);
    pInputEdit->addKeyListener(this);
    addAndMakeVisible(pInputEdit);
    
    pAddButton = new TextButton("Add Button");
    pAddButton->setButtonText(tr("Добавить"));
    pAddButton->addListener(this);
    addAndMakeVisible(pAddButton);
    
    pDeleteButton = new TextButton("Delete Button");
    pDeleteButton->setButtonText(tr("Удалить"));
    pDeleteButton->addListener(this);
    addAndMakeVisible(pDeleteButton);
    
    setSize (400, 200);
}
//---------------------------------------------------------------------
TCentralComponent::~TCentralComponent()
{
    // Удаляем дочерние виджеты
    // и обнуляем их указатели
    deleteAllChildren();
    
    if(pListBoxModel != 0)
    {
        delete pListBoxModel;
    }
}
//---------------------------------------------------------------------
void TCentralComponent::paint(Graphics& Canvas)
{
    Canvas.fillAll(Colours::azure);
}
//---------------------------------------------------------------------
void TCentralComponent::resized()
{
    pList->setBounds(10, 10, proportionOfWidth(0.5000f), 150);
    pInputEdit->setBounds(10 + (proportionOfWidth(0.5000f)) - -18, 10, proportionOfWidth(0.4f), 25);
    pAddButton->setBounds(10 + (proportionOfWidth(0.5000f)) - -18, 40, 150, 25);
    pDeleteButton->setBounds(10 + (proportionOfWidth(0.5000f)) - -18, 70, 150, 25);
}
//---------------------------------------------------------------------
void TCentralComponent::AddItem()
{
    // Если поле ввода не пусто...
    if(pInputEdit->getText().isNotEmpty())
    {
        // добавляем текст из него в список строк модели
        pListBoxModel->AddItem(pInputEdit->getText());
        // Обновляем содержимое списка для того,
        // чтобы отобразить изменение данных модели
        pList->updateContent();
        // Очищаем поле ввода
        pInputEdit->clear();
    }
}
//---------------------------------------------------------------------
void TCentralComponent::DeleteItem()
{
    // Получаем последний выбранный элемент списка
    int iSelected = pList->getLastRowSelected();
    // Если хотя бы один элемент выбран...
    if(iSelected != -1)
    {
        // удаляем строку с соответствущим индексом из массива модели
        pListBoxModel->DeleteItem(iSelected);
        // Обновляем содержимое списка для того,
        // чтобы отобразить изменение данных модели
        pList->updateContent();
    }
}
//---------------------------------------------------------------------
void TCentralComponent::buttonClicked(Button* pButton)
{
    // Если нажата кнопка "Добавить"...
    if(pButton == pAddButton)
    {
        this->AddItem();
    }
    // Если нажата кнопка "Удалить"...
    else if(pButton == pDeleteButton)
    {
        this->DeleteItem();
    }
}
//---------------------------------------------------------------------
bool TCentralComponent::keyPressed(const KeyPress& Key, Component* pComponent)
{
    // Если над полем ввода нажата клавиша <ENTER>...
    if(Key == KeyPress::returnKey && pComponent == pInputEdit)
    {
        this->AddItem();
        return true;
    }
    // Если над полем ввода нажата клавиша <DELETE>...
    else if(Key == KeyPress::deleteKey && pComponent == pList)
    {
        this->DeleteItem();
        return true;
    }
    else return false;
}
//---------------------------------------------------------------------
