/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TTableListBox.h"
//---------------------------------------------------------------------
#define tr(s) String::fromUTF8(s)
//---------------------------------------------------------------------
TTableListBox::TTableListBox(const String& sName, TableListBoxModel* pModel) 
    : TableListBox(sName, pModel)
{
    setModel(this);
    setOutlineThickness(1);
    setSize(500, 200);
    
    this->getHeader().addColumn(tr("№"), 1, 50, 30, 400, TableHeaderComponent::defaultFlags);
    this->getHeader().addColumn(tr("Имя"), 2, 100, 50, 400, TableHeaderComponent::defaultFlags);
    this->getHeader().addColumn(tr("Телефон"), 3, 100, 50, 400, TableHeaderComponent::defaultFlags);
    this->getHeader().addColumn(tr("Email"), 4, 200, 50, 400, TableHeaderComponent::defaultFlags);

    this->getHeader().setStretchToFitActive(true);

    setMultipleSelectionEnabled(true);
    
    sCells[0][1] += "1"; 
    sCells[1][1] += "2";
    sCells[2][1] += "3";
    sCells[3][1] += "4";
    
    sCells[0][2] += tr("Винни-Пух"); 
    sCells[1][2] += tr("Иа-Иа"); 
    sCells[2][2] += tr("Пятачок"); 
    sCells[3][2] += tr("Тигра");
    
    sCells[0][3] += "55-55-01";
    sCells[1][3] += "55-55-02";
    sCells[2][3] += "55-55-03";
    sCells[3][3] += "55-55-04";

    sCells[0][4] += tr("thepooh@wonderwood.uk"); 
    sCells[1][4] += tr("eyeore@wonderwood.uk"); 
    sCells[2][4] += tr("piglet@wonderwood.uk"); 
    sCells[3][4] += tr("tiger@wonderwood.uk");
}
//---------------------------------------------------------------------
TTableListBox::~TTableListBox()
{
}
//---------------------------------------------------------------------
int TTableListBox::getNumRows()
{
    return 4;
}
//---------------------------------------------------------------------
void TTableListBox::paintRowBackground(Graphics& Painter, int iRowNumber, int iWidth, int iHeight, bool bIsRowSelected)
{
    // Если строка выбрана...
    if(bIsRowSelected)
    {
        // Закрашиваем её фон бледно-голубым
        Painter.fillAll(Colours::lightblue);
    }
}
//---------------------------------------------------------------------
void TTableListBox::paintCell(Graphics& Painter, int iRowNumber, int iColumnID, int iWidth, int iHeight, bool bIsRowSelected)
{
    Painter.setColour(Colours::black);
    Painter.setFont(iHeight * 0.7f);
    
    // Рисуем текст из строковой матрицы модели в соответствующей
    // ячейке таблицы
    Painter.drawText(sCells[iRowNumber][iColumnID], 2, 0, iWidth - 4, iHeight, Justification::centredLeft, true);

    // Рисуем границы ячейки серым цветом
    Painter.setColour(Colours::black.withAlpha(0.2f));
    Painter.fillRect(iWidth - 1, 0, 1, iHeight);
}
//---------------------------------------------------------------------
void TTableListBox::backgroundClicked()
{
    // Отменяем выделение строк, если они были выбраны
    deselectAllRows();
}
//---------------------------------------------------------------------
void TTableListBox::cellDoubleClicked(int iRowNumber, int iColumn, const MouseEvent& Event)
{
    String sTitle;
    if(iColumn == 1)
    {
        sTitle = tr("Номер:");
    }
    if(iColumn == 2)
    {
        sTitle = tr("Имя:");
    }
    if(iColumn == 3)
    {
        sTitle = tr("Телефон:");
    }
    if(iColumn == 4)
    {
        sTitle = tr("Электронная почта:");
    }

    // Выводим текст соответствующей ячейки в диалоговом окне
    AlertWindow::showMessageBox(AlertWindow::InfoIcon, sTitle, sCells[iRowNumber][iColumn], tr("Да"), 0);
}
//---------------------------------------------------------------------
